@@ -46,6 +46,13 @@
 #include "epoxy/glx.h"
 #endif
 #if PLATFORM_HAS_EGL
+# if !ENABLE_X11
+/* Mesa uses this symbol to avoid including X11 headers when including
+ * EGL.h; since X11 was explicitly disabled at configuration time, we
+ * should do the same
+ */
+#  define MESA_EGL_NO_X11_HEADERS 1
+# endif
 #include "epoxy/egl.h"
 #endif
 #if PLATFORM_HAS_WGL
@@ -165,13 +172,13 @@ bool epoxy_conservative_has_wgl_extension(const char *name);
 void *epoxy_conservative_egl_dlsym(const char *name, bool exit_if_fails);
 void *epoxy_conservative_glx_dlsym(const char *name, bool exit_if_fails);
 
-bool epoxy_extension_in_string(const char *extension_list, const char *ext);
-
 #define glBegin_unwrapped epoxy_glBegin_unwrapped
 #define glEnd_unwrapped epoxy_glEnd_unwrapped
 extern void UNWRAPPED_PROTO(glBegin_unwrapped)(GLenum primtype);
 extern void UNWRAPPED_PROTO(glEnd_unwrapped)(void);
 
+extern epoxy_resolver_failure_handler_t epoxy_resolver_failure_handler;
+
 #if USING_DISPATCH_TABLE
 void gl_init_dispatch_table(void);
 void gl_switch_to_dispatch_table(void);
